@@ -9,7 +9,7 @@ use File::Which;
 use Sys::Cmd;
 use Sys::Cmd::Mo qw/is default/;
 
-our $VERSION = '0.81.8';
+our $VERSION = '0.81.9_1';
 our $CONFESS;
 
 sub cmd_template {
@@ -152,7 +152,7 @@ Sys::Cmd::Template - command/process templates for Sys::Cmd
 
 =head1 VERSION
 
-0.81.8 (2014-10-31) Development release
+0.81.9_1 (2014-11-04) Development release
 
 =head1 SYNOPSIS
 
